==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/LinearSolvers/TSFBlockTriangularSolverDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFBLOCKTRIANGULARSOLVER_DECL_HPP
#define TSFBLOCKTRIANGULARSOLVER_DECL_HPP

#include "SundanceDefs.hpp"
#include "TSFLinearSolverDecl.hpp" 


namespace TSFExtended
{
/** */
template <class Scalar>
class BlockTriangularSolver : public LinearSolverBase<Scalar>,
                              public SundanceUtils::Handleable<LinearSolverBase<Scalar> >
{
public:
  /** */
  BlockTriangularSolver(const LinearSolver<Scalar>& solver);

  /** */
  BlockTriangularSolver(const Array<LinearSolver<Scalar> >& solvers);

  /** */
  virtual ~BlockTriangularSolver(){}

  /** */
  virtual SolverState<Scalar> solve(const LinearOperator<Scalar>& op,
    const Vector<Scalar>& rhs,
    Vector<Scalar>& soln) const ;

  /* */
  GET_RCP(LinearSolverBase<Scalar>);
private:
  Array<LinearSolver<Scalar> > solvers_;
};

}

#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/LinearSolvers/TSFBlockTriangularSolverDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFBLOCKTRIANGULARSOLVER_DECL_HPP
#define TSFBLOCKTRIANGULARSOLVER_DECL_HPP

#include "SundanceDefs.hpp"
#include "TSFLinearSolverDecl.hpp" 


namespace TSFExtended
{
/** */
template <class Scalar>
class BlockTriangularSolver : public LinearSolverBase<Scalar>,
                              public Sundance::Handleable<LinearSolverBase<Scalar> >
{
public:
  /** */
  BlockTriangularSolver(const LinearSolver<Scalar>& solver);

  /** */
  BlockTriangularSolver(const Array<LinearSolver<Scalar> >& solvers);

  /** */
  virtual ~BlockTriangularSolver(){}

  /** */
  virtual SolverState<Scalar> solve(const LinearOperator<Scalar>& op,
    const Vector<Scalar>& rhs,
    Vector<Scalar>& soln) const ;

  /* */
  GET_RCP(LinearSolverBase<Scalar>);
private:
  Array<LinearSolver<Scalar> > solvers_;
};

}

#endif
